@@ -1,7 +1,7 @@
 
 #' @title Pull ACS data on field of bachelor's degree
 #' @description Pull ACS data for a specified geography from base tables
-#' B15011, and B15012. Note: only 2014 data is supplied by ACS
+#' B15011 and B15012. Note: only 2014 data is supplied by ACS
 #' @param endyear An integer, indicating the latest year of the data in the survey.
 #' @param span An integer in \code{c(1,3,5)} indicating the span of the desired data.
 #' @param geography a valid \code{geo.set} object specifying the census geography or 
@@ -18,17 +18,20 @@ pull_bachelors <- function(endyear, span, geography) {
   
   # 01 -- pull data and move to lists
   #----------------------------------------------
+  oldw <- getOption("warn")
+  options(warn= -1) # suppress warnings from library(acs) / ACS API
   # ba_deg25up <- acs.fetch(endyear= 2014, span= 5, geography= la_tracts, table.number = "C15010",
   #                    col.names= "pretty")
   by_sex_age <- acs::acs.fetch(endyear = endyear, span= span, geography = geography, table.number = "B15011",
                      col.names = "pretty")
   ba_total <- acs::acs.fetch(endyear = endyear, span= span, geography = geography, table.number = "B15012",
                      col.names = "pretty")
+  options(warn= oldw) # turn warnings back on
   
   
-  est <- list(by_sex_age= data.frame(by_sex_age@estimate[,c(1,2,21, 3:20, 22:39)]),
-              ba_total= data.frame(ba_total@estimate))
-  se <- list(by_sex_age= data.frame(by_sex_age@standard.error[,c(1,2,21, 3:20, 22:39)]),
+  est <- list(by_sex_age= as.data.frame(t(by_sex_age@estimate[,c(1,2,21, 3:20, 22:39)])),
+              ba_total= as.data.frame(ba_total@estimate))
+  se <- list(by_sex_age= data.frame(t(by_sex_age@standard.error[,c(1,2,21, 3:20, 22:39)])),
              ba_total= data.frame(ba_total@standard.error))
   geo <- by_sex_age@geography
   
